/* @(#)unloadinfo.c	1.6 9/4/92 */
/***************************************************************************/
/*
        Name: unloadinfo.c
 Description: Unloads an INFO data file to a system file.  Unloaded values
                are output one value per line and are left justified.  Unload
                status is directed to stdout.
     History: 01/92  Todd Stellhorn  - original coding
              04/92  Todd Stellhorn  - final coding
              05/92  Todd Stellhorn  - removed string compression on 
                                         CHAR item output
              09/92  Todd Stellhorn  - flush stdout
 */
/***************************************************************************/

#include <stdio.h>
#include <string.h>
#include "infotools.h"

/***************************************************************************/

#define USAGE "usage: unloadinfo <INFO_File> <Item> <Out_File>"

short int OutputRecord();

/***************************************************************************/

int main( argc, argv )

int argc;
char **argv;

/***************************************************************************/
/*
       Name: main
    Purpose: Main unloadinfo function.
     Inputs: INFO_File - name of the input INFO file
             Item - unload item 
             Out_File - name of the output text file
    Outputs: Function ( int ) - function status
             Unloaded data is written to <Out_File>.
    History: 01/92  Todd Stellhorn  - original coding
             04/92  Todd Stellhorn  - final coding
 */
{
      char              *InfoFilePath;
      char              *OutputItem;
      char              *OutputFile;
      InfoFile          *FilePtr;
      InfoItemDef       *OutputItemPtr;
      long int           i;
      FILE              *outfp;

/* check args */

      if( argc != 4 )
           FatalError( USAGE );

      InfoFilePath = argv[1];
      OutputItem = argv[2];
      OutputFile = argv[3];

/* open file */

      if(( FilePtr = InfoOpenFile( InfoFilePath, InfoREAD )) ==  
           ( InfoFile * ) NULL )
           FatalError( "Cannot open INFO file." );

/* get OutputItemName ItemDef */

      if(( OutputItemPtr = InfoGetItemDef( FilePtr, OutputItem )) ==  
           ( InfoItemDef * ) NULL )
           FatalError( "Cannot find item." );

/* open output file */
 
      if(( outfp = fopen( OutputFile, "w" )) == NULL )
           FatalError( "Cannot open <Out_File>." );

/* for each record */

      for( i = 1; i <= FilePtr->NumberRecords; i++ )
      {
           if( ! InfoReadRecord( FilePtr, i ))
                FatalError( "Error reading record." );

           if( ! OutputRecord( FilePtr, OutputItemPtr, outfp ))
                FatalError( "Error outputing record." );
      }

/* close up shop */

      if( ! InfoCloseFile( FilePtr ))
           FatalError( "Error closing INFO file." );

      fprintf( stdout, OK_STRING );
      fflush( stdout );

      return( 0 );
}                                           /* end of main                 */


/***************************************************************************/

short int OutputRecord( InfoFilePtr, ItemPtr, outfp )

InfoFile *InfoFilePtr;
InfoItemDef *ItemPtr;
FILE *outfp;

/***************************************************************************/
/*
       Name: OutputRecord
    Purpose: Unloads the input item to stdout.
     Inputs: InfoFilePtr ( InfoFile * ) - INFO file pointer
             ItemPtr ( InfoItemDef * ) - item pointer 
             outfp ( FILE * ) - outfile pointer
    Outputs: Function ( short int ) - function stauts
             Output item values are written to outfp.
    History: 01/92  Todd Stellhorn  - original coding
             04/92  Todd Stellhorn  - final coding
 */
{
      char              RetString[4096];
      char              TmpString[4096];
      double            DRetVal;

      if( ! InfoDecode( InfoFilePtr, ItemPtr, RetString, &DRetVal ))
           return( 0 );

      switch( ItemPtr->ItemType )
      {
           case INFO_DATE_TYPE         :  

                return( 0 );

           case INFO_CHARACTER_TYPE    :

                strcpy( TmpString, RetString );
                break;

           case INFO_INTEGER_TYPE      :

                sprintf( TmpString, "%-d", ( int ) DRetVal );
                break;

           case INFO_NUMBER_TYPE       : 

                sprintf( TmpString, "%-lf", DRetVal );
                break;

           case INFO_BINARY_TYPE       :

                sprintf( TmpString, "%-d", ( int ) DRetVal );
                break;

           case INFO_FLOATING_TYPE     :

                sprintf( TmpString, "%-lf", DRetVal );
                break;

           case INFO_LEADFILL_TYPE     :
           case INFO_PACKED_TYPE       :
           case INFO_ZEROFILL_TYPE     :
           case INFO_OVERPUNCH_TYPE    :
           case INFO_TRAILINGSIGN_TYPE :
           case INFO_RECNO_TYPE        :
           default                     :

                return( 0 );
      }

      fprintf( outfp, "%s\n", TmpString );

      return( 1 );
}                                           /* end of OutputRecord         */

/*                                             end of unloadinfo.c         */